diff src/video/uikit/SDL_uikitview.m @ 5223:572a73d71b5f

Sheena pointed out that "scancode" and "keysym" are single words and shouldn't be camel-cased.
author Sam Lantinga <slouken@libsdl.org>
date Mon, 07 Feb 2011 09:37:11 -0800
parents c63b901d97ab
children b530ef003506
line wrap: on
line diff
--- a/src/video/uikit/SDL_uikitview.m	Mon Feb 07 09:23:01 2011 -0800
+++ b/src/video/uikit/SDL_uikitview.m	Mon Feb 07 09:37:11 2011 -0800
@@ -267,10 +267,10 @@
             unichar c = [string characterAtIndex: i];
             
             Uint16 mod = 0;
-            SDL_ScanCode code;
+            SDL_Scancode code;
             
             if (c < 127) {
                 /* figure out the SDL_ScanCode and SDL_keymod for this unichar */
                 code = unicharToUIKeyInfoTable[c].code;
                 mod  = unicharToUIKeyInfoTable[c].mod;
             }
@@ -267,10 +267,10 @@
             
             if (c < 127) {
-                /* figure out the SDL_ScanCode and SDL_keymod for this unichar */
+                /* figure out the SDL_Scancode and SDL_keymod for this unichar */
                 code = unicharToUIKeyInfoTable[c].code;
                 mod  = unicharToUIKeyInfoTable[c].mod;